@@ -12,6 +12,9 @@
 #include <cassert>
 #include <vector>
 #include <type_traits> // is_same.
+#include <cmath> // abs
+#include <complex>
+#include <limits> // epsilon
 
 #include <Eigen/Sparse>
 #include <Eigen/IterativeLinearSolvers>
@@ -229,6 +232,7 @@ class arpackSolver {
 
     int solve(EM & A, EM const * B = nullptr) {
       stdPb = !B ? true : false;
+      if (nbCV > A.cols()) nbCV = A.cols(); // Cut-off arpack workspace dim.
 
       dumpParameters();
       if (verbose == 3) {
@@ -244,7 +248,7 @@ class arpackSolver {
 
       // If needed, transform the initial problem into a new one that arpack can handle.
 
-      auto eps = numeric_limits<double>::epsilon();
+      auto eps = numeric_limits<FD>::epsilon();
       bool shiftReal = (fabs(sigmaReal) > eps) ? true : false;
       bool shiftImag = (fabs(sigmaImag) > eps) ? true : false;
       bool backTransform = false;
@@ -346,13 +350,13 @@ class arpackSolver {
 
   private:
 
-    void makeZero(         float  & zero) {zero = 0.f;};
+    void makeConstant(         float  & cst,  float const & val) {cst = val;};
 
-    void makeZero(        double  & zero) {zero = 0.;};
+    void makeConstant(        double  & cst, double const & val) {cst = val;};
 
-    void makeZero(complex< float> & zero) {zero = complex<double>(0.f, 0.f);};
+    void makeConstant(complex< float> & cst,  float const & val) {cst = complex<float>(val, val);};
 
-    void makeZero(complex<double> & zero) {zero = complex<double>(0., 0.);};
+    void makeConstant(complex<double> & cst, double const & val) {cst = complex<double>(val, val);};
 
     int readMatrixMarket(string const & fileName,
                          a_uint & n, a_uint & m, vector<a_uint> & i, vector<a_uint> & j, vector<RC> & Mij) {
@@ -387,7 +391,7 @@ class arpackSolver {
         }
         else { // Body.
           a_uint k = 0, l = 0;
-          RC zero; makeZero(zero);
+          RC zero; makeConstant(zero, 0.);
           RC Mkl = zero;
           inpSS >> k >> l >> Mkl;
           if (!inpSS) {cerr << "Error: bad line (" << fileName << ", line " << l << ")" << endl; return 1;}
@@ -401,9 +405,11 @@ class arpackSolver {
       // Handle 1-based -> 0-based.
 
       nnz = i.size(); // In case nnz was not provided.
-      if (*max_element(begin(i), end(i)) == n || *max_element(begin(j), end(j)) == m) {
-        for (size_t k = 0; k < nnz; k++) i[k] -= 1;
-        for (size_t k = 0; k < nnz; k++) j[k] -= 1;
+      if (nnz > 0) {
+        if (*max_element(begin(i), end(i)) == n || *max_element(begin(j), end(j)) == m) {
+          for (size_t k = 0; k < nnz; k++) i[k] -= 1;
+          for (size_t k = 0; k < nnz; k++) j[k] -= 1;
+        }
       }
 
       return 0;
@@ -437,18 +443,18 @@ class arpackSolver {
               a_int ldv, a_int * iparam, a_int * ipntr, complex<float> * workd, complex<float> * workl, a_int lworkl, float * & rwork,
               a_int * info) {
       if (!rwork) rwork = new float[nbCV];
-      cnaupd_c(ido, bMat, nbDim, which, nbEV, tol, reinterpret_cast<_Complex float*>(resid), nbCV,
-               reinterpret_cast<_Complex float*>(v), ldv, iparam, ipntr, reinterpret_cast<_Complex float*>(workd),
-               reinterpret_cast<_Complex float*>(workl), lworkl, rwork, info);
+      cnaupd_c(ido, bMat, nbDim, which, nbEV, tol, reinterpret_cast<a_fcomplex*>(resid), nbCV,
+               reinterpret_cast<a_fcomplex*>(v), ldv, iparam, ipntr, reinterpret_cast<a_fcomplex*>(workd),
+               reinterpret_cast<a_fcomplex*>(workl), lworkl, rwork, info);
     };
 
     void aupd(a_int * ido, char const * bMat, a_int nbDim, char const * which, complex<double> * resid, complex<double> * v,
               a_int ldv, a_int * iparam, a_int * ipntr, complex<double> * workd, complex<double> * workl, a_int lworkl, double * & rwork,
               a_int * info) {
       if (!rwork) rwork = new double[nbCV];
-      znaupd_c(ido, bMat, nbDim, which, nbEV, tol, reinterpret_cast<_Complex double*>(resid), nbCV,
-               reinterpret_cast<_Complex double*>(v), ldv, iparam, ipntr, reinterpret_cast<_Complex double*>(workd),
-               reinterpret_cast<_Complex double*>(workl), lworkl, rwork, info);
+      znaupd_c(ido, bMat, nbDim, which, nbEV, tol, reinterpret_cast<a_dcomplex*>(resid), nbCV,
+               reinterpret_cast<a_dcomplex*>(v), ldv, iparam, ipntr, reinterpret_cast<a_dcomplex*>(workd),
+               reinterpret_cast<a_dcomplex*>(workl), lworkl, rwork, info);
     };
 
     void spectrum(RC * d, RC * z, a_int nbDim, a_int * iparam) {
@@ -517,8 +523,8 @@ class arpackSolver {
 
         sseupd_c(rvec, howmny, select, d, z, ldz, sigmaReal,
                  bMat, nbDim, which, nbEV, tol, resid, nbCV, v, ldv, iparam, ipntr, workd, workl, lworkl, &info);
-        if (info == -14) cerr << "Error: dseupd - KO: dsaupd did not find any eigenvalues to sufficient accuracy" << endl;
-        if (info < 0 && info != -14 /*-14: don't break*/) {cerr << "Error: dseupd - KO with info " << info << endl; return 1;}
+        if (info == -14) cerr << "Error: sseupd - KO: ssaupd did not find any eigenvalues to sufficient accuracy" << endl;
+        if (info < 0 && info != -14 /*-14: don't break*/) {cerr << "Error: sseupd - KO with info " << info << endl; return 1;}
 
         spectrum(d, z, nbDim, iparam);
 
@@ -531,8 +537,8 @@ class arpackSolver {
 
         sneupd_c(rvec, howmny, select, dr, di, z, ldz, sigmaReal, sigmaImag, workev,
                  bMat, nbDim, which, nbEV, tol, resid, nbCV, v, ldv, iparam, ipntr, workd, workl, lworkl, &info);
-        if (info == -14) cerr << "Error: dneupd - KO: [dz]naupd did not find any eigenvalues to sufficient accuracy" << endl;
-        if (info < 0 && info != -14 /*-14: don't break*/) {cerr << "Error: dneupd - KO with info " << info << endl; return 1;}
+        if (info == -14) cerr << "Error: sneupd - KO: snaupd did not find any eigenvalues to sufficient accuracy" << endl;
+        if (info < 0 && info != -14 /*-14: don't break*/) {cerr << "Error: sneupd - KO with info " << info << endl; return 1;}
 
         halfSpectrum(dr, di, z, nbDim, iparam);
 
@@ -568,7 +574,7 @@ class arpackSolver {
 
         dneupd_c(rvec, howmny, select, dr, di, z, ldz, sigmaReal, sigmaImag, workev,
                  bMat, nbDim, which, nbEV, tol, resid, nbCV, v, ldv, iparam, ipntr, workd, workl, lworkl, &info);
-        if (info == -14) cerr << "Error: dneupd - KO: [dz]naupd did not find any eigenvalues to sufficient accuracy" << endl;
+        if (info == -14) cerr << "Error: dneupd - KO: dnaupd did not find any eigenvalues to sufficient accuracy" << endl;
         if (info < 0 && info != -14 /*-14: don't break*/) {cerr << "Error: dneupd - KO with info " << info << endl; return 1;}
 
         halfSpectrum(dr, di, z, nbDim, iparam);
@@ -589,13 +595,13 @@ class arpackSolver {
       complex<float> * workev = new complex<float>[2*nbCV];
 
       complex<float> sigma = complex<float>((float) sigmaReal, (float) sigmaImag);
-      cneupd_c(rvec, howmny, select, reinterpret_cast<_Complex float*>(d), reinterpret_cast<_Complex float*>(z), ldz,
-               reinterpret_cast<_Complex float &>(sigma), reinterpret_cast<_Complex float*>(workev),
-               bMat, nbDim, which, nbEV, tol, reinterpret_cast<_Complex float*>(resid), nbCV,
-               reinterpret_cast<_Complex float*>(v), ldv, iparam, ipntr,
-               reinterpret_cast<_Complex float*>(workd), reinterpret_cast<_Complex float*>(workl), lworkl, rwork, &info);
-      if (info == -14) cerr << "Error: zneupd - KO: dsaupd did not find any eigenvalues to sufficient accuracy" << endl;
-      if (info < 0 && info != -14 /*-14: don't break*/) {cerr << "Error: zneupd - KO with info " << info << endl; return 1;}
+      cneupd_c(rvec, howmny, select, reinterpret_cast<a_fcomplex*>(d), reinterpret_cast<a_fcomplex*>(z), ldz,
+               reinterpret_cast<a_fcomplex &>(sigma), reinterpret_cast<a_fcomplex*>(workev),
+               bMat, nbDim, which, nbEV, tol, reinterpret_cast<a_fcomplex*>(resid), nbCV,
+               reinterpret_cast<a_fcomplex*>(v), ldv, iparam, ipntr,
+               reinterpret_cast<a_fcomplex*>(workd), reinterpret_cast<a_fcomplex*>(workl), lworkl, rwork, &info);
+      if (info == -14) cerr << "Error: cneupd - KO: cnaupd did not find any eigenvalues to sufficient accuracy" << endl;
+      if (info < 0 && info != -14 /*-14: don't break*/) {cerr << "Error: cneupd - KO with info " << info << endl; return 1;}
 
       spectrum(d, z, nbDim, iparam);
 
@@ -613,12 +619,12 @@ class arpackSolver {
       complex<double> * workev = new complex<double>[2*nbCV];
 
       complex<double> sigma = complex<double>(sigmaReal, sigmaImag);
-      zneupd_c(rvec, howmny, select, reinterpret_cast<_Complex double*>(d), reinterpret_cast<_Complex double*>(z), ldz,
-               reinterpret_cast<_Complex double &>(sigma), reinterpret_cast<_Complex double*>(workev),
-               bMat, nbDim, which, nbEV, tol, reinterpret_cast<_Complex double*>(resid), nbCV,
-               reinterpret_cast<_Complex double*>(v), ldv, iparam, ipntr,
-               reinterpret_cast<_Complex double*>(workd), reinterpret_cast<_Complex double*>(workl), lworkl, rwork, &info);
-      if (info == -14) cerr << "Error: zneupd - KO: dsaupd did not find any eigenvalues to sufficient accuracy" << endl;
+      zneupd_c(rvec, howmny, select, reinterpret_cast<a_dcomplex*>(d), reinterpret_cast<a_dcomplex*>(z), ldz,
+               reinterpret_cast<a_dcomplex &>(sigma), reinterpret_cast<a_dcomplex*>(workev),
+               bMat, nbDim, which, nbEV, tol, reinterpret_cast<a_dcomplex*>(resid), nbCV,
+               reinterpret_cast<a_dcomplex*>(v), ldv, iparam, ipntr,
+               reinterpret_cast<a_dcomplex*>(workd), reinterpret_cast<a_dcomplex*>(workl), lworkl, rwork, &info);
+      if (info == -14) cerr << "Error: zneupd - KO: znaupd did not find any eigenvalues to sufficient accuracy" << endl;
       if (info < 0 && info != -14 /*-14: don't break*/) {cerr << "Error: zneupd - KO with info " << info << endl; return 1;}
 
       spectrum(d, z, nbDim, iparam);
@@ -654,22 +660,47 @@ class arpackSolver {
       return rc;
     };
 
-    void restartSolve(string const & fileName,
-                      a_int const & nbDim, RC * rv, bool readNbCV) {
-      if (restartFromFile) {
-        ifstream ifs(fileName.c_str());
-        if (ifs.is_open()) {
-          a_int nbCV = 1; if (readNbCV) {ifs >> nbCV; if (nbCV < nbCV) nbCV = nbCV;}
-          for (a_int n = 0; rv && n < nbDim*nbCV; n++) ifs >> rv[n];
-          if (verbose >= 1) {
-            cout << endl << "arpackSolver:" << endl;
-            cout << endl << fileName << ": restart OK" << endl;
-            if (verbose >= 2) {
-              for (a_int n = 0; rv && n < nbDim; n++) cout << rv[n] << endl;
-            }
+    template <typename T>
+    int saveSolve(string const & fileName,
+                  a_int const & nbDim, T * rv) {
+      ofstream ofs(fileName.c_str(), ofstream::trunc);
+      if (ofs.is_open()) {
+        ofs << nbDim << endl;
+        for (a_int n = 0; rv && n < nbDim; n++) ofs << rv[n] << endl;
+      }
+      return 0;
+    };
+
+    template <typename T>
+    int restartSolve(string const & fileName,
+                     a_int const & nbDim, T * rv,
+                     bool allowZero = true) {
+      ifstream ifs(fileName.c_str());
+      if (ifs.is_open()) {
+        a_int nDim = 0;
+        ifs >> nDim;
+        if (nDim != nbDim) {cerr << "Error: bad dim - restart KO" << endl; return 1;}
+        for (a_int n = 0; rv && n < nbDim; n++) {
+          RC val; makeConstant(val, 0.);
+          ifs >> val;
+          if (abs(val) < 1.e-6 && !allowZero) {
+            // Do NOT let residual be zero: this stops arpack to iterate (info = -9).
+            auto eps = numeric_limits<FD>::epsilon();
+            RC epsilon; makeConstant(epsilon, eps);
+            val = epsilon;
+          }
+          rv[n] = val;
+        }
+
+        if (verbose >= 1) {
+          cout << endl << "arpackSolver:" << endl;
+          cout << endl << fileName << ": restart OK" << endl;
+          if (verbose >= 2) {
+            for (a_int n = 0; rv && n < nbDim; n++) cout << rv[n] << endl;
           }
         }
       }
+      return 0;
     };
 
     int initPointerSize(a_int & iparamSz, a_int & ipntrSz, string const & aeupd) {
@@ -702,18 +733,20 @@ class arpackSolver {
       char const * gMat = "G";
       char const * bMat = (mode == 1) ? iMat : gMat;
       a_int nbDim = A.rows();
-      RC zero; makeZero(zero);
+      auto eps = numeric_limits<FD>::epsilon();
+      RC epsilon; makeConstant(epsilon, eps);
       if (!resid) {
         resid = new RC[nbDim];
-        for (a_int n = 0; n < nbDim; n++) resid[n] = zero; // Avoid "bad" starting vector.
+        // Do NOT let residual be zero: this stops arpack to iterate (info = -9).
+        for (a_int n = 0; n < nbDim; n++) resid[n] = epsilon;
       };
-      restartSolve("arpackSolver.resid.out", nbDim, resid, false);
       a_int ldv = nbDim;
+      RC cst; makeConstant(cst, 10.);
+      RC v0 = cst * epsilon; // Start with something close to zero but *not* exactly zero.
       if (!v) {
         v = new RC[ldv*nbCV];
-        for (a_int n = 0; n < ldv*nbCV; n++) v[n] = zero; // Avoid "bad" starting vector.
+        for (a_int n = 0; n < ldv*nbCV; n++) v[n] = v0;
       };
-      restartSolve("arpackSolver.v.out", ldv, v, true);
       a_int iparamSz = 0, ipntrSz = 0;
       int rc = initPointerSize(iparamSz, ipntrSz, "aupd");
       if (rc != 0) {cerr << "Error: bad iparam/ipntr initialization for aupd" << endl; return rc;}
@@ -723,12 +756,22 @@ class arpackSolver {
       iparamAupd[3] = 1; // Block size.
       iparamAupd[4] = 0; // Number of ev found by arpack.
       iparamAupd[6] = mode;
+      RC zero; makeConstant(zero, 0.);
       vector<a_int> ipntrAupd(ipntrSz, 0);
       RC * workd = new RC[3*nbDim]; for (a_int n = 0; n < 3*nbDim; n++) workd[n] = zero; // Avoid "bad" X/Y vector.
       a_int lworkl = symPb ? nbCV*nbCV + 8*nbCV : 3*nbCV*nbCV + 6*nbCV;
       RC * workl = new RC[lworkl];
       a_int info = 0; // Use random initial residual vector.
-      if (restartFromFile) info = 1;
+
+      // Handling restart.
+
+      if (restartFromFile) {
+        info = 1; // Restart.
+        rc = restartSolve("arpackSolver.resid.out", nbDim, resid, false);
+        if (rc != 0) {cerr << "Error: bad restart (resid)" << endl; return rc;}
+        rc = restartSolve("arpackSolver.v.out", ldv*nbCV, v);
+        if (rc != 0) {cerr << "Error: bad restart (v)" << endl; return rc;}
+      }
 
       // Initialize solver.
 
@@ -822,9 +865,11 @@ class arpackSolver {
       rc = eupd(rvec, howmny, select, z, ldz, bMat, nbDim, which, resid, v, ldv, iparamEupd.data(), ipntrEupd.data(), workd, workl, lworkl, rwork, info);
       if (rc != 0) {cerr << "Error: bad arpack eupd" << endl; return rc;}
 
+      // Save solve (dump results to file) to allow later restart.
+
       if (dumpToFile) {
-        ofstream rfs("arpackSolver.resid.out"); for (a_int n = 0; n < nbDim; n++) rfs << resid[n] << endl;
-        ofstream vfs("arpackSolver.v.out"); vfs << nbCV << endl; for (a_int n = 0; n < ldv*nbCV; n++) vfs << v[n] << endl;
+        saveSolve("arpackSolver.resid.out", nbDim, resid);
+        saveSolve("arpackSolver.v.out", ldv*nbCV, v);
       }
 
       // Clean.
