@@ -48,7 +48,7 @@ class options {
 
     for (int a = 1; argv && a < argc; a++) {
       string clo = argv[a];  // Command line option.
-      if (clo == "--help") return usage(0);
+      if (clo == "--help" || clo == "-h") return usage(0);
       if (clo == "--A") {
         a++;
         if (a >= argc) {
@@ -104,7 +104,7 @@ class options {
         mag = argv[a];  // small mag (likely poor perf) <=> large mag + invert
                         // (likely good perf).
         bool ok = (mag == "LM" || mag == "SM" || mag == "LR" || mag == "SR" ||
-                   mag == "LI" || mag == "SI")
+                   mag == "LA" || mag == "SA" || mag == "LI" || mag == "SI")
                       ? true
                       : false;
         if (!ok) {
@@ -167,6 +167,9 @@ class options {
           return usage();
         }
       }
+      if (clo == "--schur") {
+        schur = true;
+      }
       if (clo == "--slv") {
         a++;
         if (a >= argc) {
@@ -316,6 +319,14 @@ class options {
       }
     }
 
+    // Sanity checks.
+
+    if (!stdPb && fileB.empty()) {
+      cerr << "Error: generalized problem without B matrix"
+           << ", specify --B XX with XX being a matrix market file" << endl;
+      return usage();
+    }
+
     return 0;
   };
 
@@ -381,7 +392,7 @@ class options {
             "[dz]*upd)"
          << endl;
     cout << "  --mag M:          set magnitude of eigen values to look for "
-            "(LM, SM, LR, SR, LI, SI)."
+            "(LM, SM, LR, SR, LA, SA, LI, SI)."
          << endl;
     cout << "                    default: large magnitude (LM)" << endl;
     cout << "  --shiftReal S:    real shift where sigma = S (look for lambda+S "
@@ -548,12 +559,23 @@ ostream& operator<<(ostream& ostr, options const& opt) {
   ostr << ", invert " << (opt.invert ? "yes" : "no") << ", tol " << opt.tol
        << ", maxIt " << opt.maxIt;
   ostr << ", " << (opt.schur ? "Schur" : "Ritz") << " vectors" << endl;
-  ostr << "OPT: slv " << opt.slv << ", slvItrPC " << opt.slvItrPC
-       << ", slvItrTol " << opt.slvItrTol;
-  ostr << ", slvItrMaxIt " << opt.slvItrMaxIt << ", slvDrtPivot "
-       << opt.slvDrtPivot;
-  ostr << ", slvDrtOffset " << opt.slvDrtOffset << ", slvDrtScale "
-       << opt.slvDrtScale << endl;
+  ostr << "OPT: slv " << opt.slv;
+  bool itrSlv = true;  // Use iterative solvers.
+  if (opt.slv.find("LU") != string::npos ||
+      opt.slv.find("QR") != string::npos ||
+      opt.slv.find("LLT") != string::npos ||
+      opt.slv.find("LDLT") != string::npos)
+    itrSlv = false;
+  if (itrSlv) {
+    ostr << ", slvItrPC " << opt.slvItrPC;
+    ostr << ", slvItrTol " << opt.slvItrTol;
+    ostr << ", slvItrMaxIt " << opt.slvItrMaxIt;
+  } else {
+    ostr << ", slvDrtPivot " << opt.slvDrtPivot;
+    ostr << ", slvDrtOffset " << opt.slvDrtOffset;
+    ostr << ", slvDrtScale " << opt.slvDrtScale;
+  }
+  ostr << endl;
   ostr << "OPT: check " << (opt.check ? "yes" : "no") << ", verbose "
        << opt.verbose << ", debug " << opt.debug;
   ostr << ", restart " << (opt.restart ? "yes" : "no") << endl;
@@ -615,8 +637,6 @@ int itrSolve(options& opt, output& out, double const& slvItrILUDropTol,
   cout << endl;
   cout << "INP: create A " << readATime << " s" << endl;
 
-  if (opt.nbCV > A.cols()) opt.nbCV = A.cols(); /* Cut-off */
-
   EM B;
   if (!opt.stdPb) {
     start = chrono::high_resolution_clock::now();
@@ -704,8 +724,6 @@ int drtSolve(options& opt, output& out) {
   cout << endl;
   cout << "INP: create A " << readATime << " s" << endl;
 
-  if (opt.nbCV > A.cols()) opt.nbCV = A.cols(); /* Cut-off */
-
   EM B;
   if (!opt.stdPb) {
     start = chrono::high_resolution_clock::now();
@@ -844,6 +862,7 @@ int main(int argc, char** argv) {
   if (opt.dense) {
     if (itrSlv) {
       cerr << "Error: dense matrices does not support iterative solvers"
+           << ", specify --slv XX with XX being a direct solver"
            << endl;
       return 1;
     }
