@@ -177,8 +177,8 @@ c
       Double precision
      &           dznrm2, dlapy2
       Complex*16
-     &           zdotc
-      external   zdotc, dznrm2, dlapy2
+     &           zzdotc
+      external   zzdotc, dznrm2, dlapy2
 c
 c     %-----------------%
 c     | Data Statements |
@@ -293,8 +293,8 @@ c
 c
       first = .FALSE.
       if (bmat .eq. 'G') then
-          cnorm  = zdotc (n, resid, 1, workd, 1)
-          rnorm0 = sqrt(dlapy2(dble(cnorm),dimag(cnorm)))
+          cnorm  = zzdotc (n, resid, 1, workd, 1)
+          rnorm0 = sqrt(dlapy2(dble(cnorm),aimag(cnorm)))
       else if (bmat .eq. 'I') then
            rnorm0 = dznrm2(n, resid, 1)
       end if
@@ -350,8 +350,8 @@ c
       end if
 c
       if (bmat .eq. 'G') then
-         cnorm = zdotc (n, resid, 1, workd, 1)
-         rnorm = sqrt(dlapy2(dble(cnorm),dimag(cnorm)))
+         cnorm = zzdotc (n, resid, 1, workd, 1)
+         rnorm = sqrt(dlapy2(dble(cnorm),aimag(cnorm)))
       else if (bmat .eq. 'I') then
          rnorm = dznrm2(n, resid, 1)
       end if
